@@ -1,7 +1,7 @@
 import subprocess
 import click
 
-script ="./createnv.sh"
+script ="createnv.sh"
 # test = subprocess.run(["./createnv.sh","name",],check=True)
 # print(test.returncode)
 # print(test.args)
@@ -13,7 +13,7 @@ def cli(name,dependencies):
     specify package names after name flag to install them,read documentation for how that works
     """
     if not dependencies:
-        commands = [script, name]
+        commands = ["bash",script, name]
         try:
              process = subprocess.run(commands)
              if process.returncode == 0:
@@ -24,6 +24,7 @@ def cli(name,dependencies):
     commands = list(dependencies)
     commands.insert(0,name)
     commands.insert(0,script)
+    commands.insert(0,"bash")
     try:
         process = subprocess.run(commands)
     except Exception as e:
